';
- $html->select_product_fourn_price($objp->fk_product,'productfournpriceid');
+
+ $formMarkup = '
'."\n";
+ $formMarkup.= ajax_updaterWithID("rate".$i,"markup","sellingprice_ht".$i,"/product/ajaxproducts.php","&count=".$i,"working")."\n";
+
+
+ print '
'."\n";
+
+ print ' '."\n";
+ print $formMarkup."\n";
print ' '."\n";
- print ' | ';
+
print '';
print ' | ';
@@ -1244,24 +1285,34 @@ if ($_GET['propalid'] > 0)
print ' - '.nl2br($objp->product);
print '
';
}
- // éditeur wysiwyg
- if ($conf->fckeditor->enabled && $conf->global->FCKEDITOR_ENABLE_DETAILS)
+ if ($_GET["action"] == 'editline')
{
- require_once(DOL_DOCUMENT_ROOT."/lib/doleditor.class.php");
- $doleditor=new DolEditor('desc',$objp->description,164,'dolibarr_details');
- $doleditor->Create();
- }
- else
- {
- print '
';
+ // éditeur wysiwyg
+ if ($conf->fckeditor->enabled && $conf->global->FCKEDITOR_ENABLE_DETAILS)
+ {
+ require_once(DOL_DOCUMENT_ROOT."/lib/doleditor.class.php");
+ $doleditor=new DolEditor('desc',$objp->description,164,'dolibarr_details');
+ $doleditor->Create();
+ }
+ else
+ {
+ print '
';
+ }
}
print '';
- if ($conf->global->PRODUIT_USE_MARKUP) print '
| ';
+ if ($conf->global->PRODUIT_USE_MARKUP)
+ {
+ print '
'.vatrate($objp->marge_tx).'% | ';
+ }
print '
';
if($societe->tva_assuj == "0")
- print '0';
+ {
+ print '0';
+ }
else
- print $html->select_tva("tva_tx",$objp->tva_tx,$mysoc,$societe);
+ {
+ print $html->select_tva("tva_tx",$objp->tva_tx,$mysoc,$societe);
+ }
print ' | ';
print '
| ';
print '
';
diff --git a/htdocs/html.form.class.php b/htdocs/html.form.class.php
index d5010473c74..646c2132fff 100644
--- a/htdocs/html.form.class.php
+++ b/htdocs/html.form.class.php
@@ -73,7 +73,7 @@ class Form
\param img Code img du picto
\return string Code html du texte,picto
*/
- function textwithtooltip($text,$htmltext,$tooltipon=1,$direction=0,$img='',$i=1,$option='')
+ function textwithtooltip($text,$htmltext,$tooltipon=1,$direction=0,$img='',$i=1,$width='200',$shiftX='10',$option='')
{
global $conf;
@@ -95,7 +95,7 @@ class Form
$s.= $htmltext."\n";
$s.= ''."\n";
$s.= ''."\n";
}
@@ -1264,15 +1264,15 @@ class Form
{
$num = $this->db->num_rows($result);
- print '';
$this->db->free($result);
}
+ return $form;
}
else
{
diff --git a/htdocs/lib/lib_head.js b/htdocs/lib/lib_head.js
index 5bf4fe3e0ae..863bb79ffaa 100644
--- a/htdocs/lib/lib_head.js
+++ b/htdocs/lib/lib_head.js
@@ -677,4 +677,27 @@ function dialogConfirm(linkurl,message,ok,cancel,objectID) {
==================================================================*/
function dialogInfo(message) {
Dialog.info(message, {width:700});
+}
+
+/*=================================================================
+ Purpose: Affiche une fenetre
+ Input: message
+ Author: Regis Houssin
+ Licence: GPL
+==================================================================*/
+function dialogWindow(message,windowTitle) {
+var win = new Window({className: "dialog",
+ width:600,
+ height:400,
+ zIndex: 100,
+ resizable: false,
+ title: windowTitle,
+ showEffect:Effect.BlindDown,
+ hideEffect: Effect.SwitchOff,
+ draggable:true
+ })
+/*win.setHTMLContent(message);*/
+/*win.getContent().innerHTML = message;*/
+win.getContent().update(message);
+win.showCenter();
}
\ No newline at end of file
diff --git a/htdocs/product/ajaxproducts.php b/htdocs/product/ajaxproducts.php
index 9a0c48d7bf9..a6b0fdae4af 100644
--- a/htdocs/product/ajaxproducts.php
+++ b/htdocs/product/ajaxproducts.php
@@ -49,6 +49,20 @@ if(isset($_GET['keysearch']) && !empty($_GET['keysearch']))
$form->select_produits_fournisseurs_do($_GET["socid"],"",$_GET["htmlname"],"","",$_GET["keysearch"]);
}
}
+else if(isset($_GET['markup']) && !empty($_GET['markup']))
+{
+ print $_GET['markup'];
+ //print $_GET['count'];
+ //$field = "";
+ //print '';
+ //print $field;
+}
+else if(isset($_GET['selling']) && !empty($_GET['selling']))
+{
+ //print $_GET['markup'];
+ //print $_GET['count'];
+ print '';
+}
print " |
diff --git a/htdocs/includes/scriptaculous/lib/prototype.js b/htdocs/includes/scriptaculous/lib/prototype.js
index 5d2100fac2d..e85c94c5a67 100644
--- a/htdocs/includes/scriptaculous/lib/prototype.js
+++ b/htdocs/includes/scriptaculous/lib/prototype.js
@@ -1,52 +1,111 @@
/* Prototype JavaScript framework, version 1.5.1
* (c) 2005-2007 Sam Stephenson
*
* Prototype is freely distributable under the terms of an MIT-style license.
* For details, see the Prototype web site: http://www.prototypejs.org/
*
-/*--------------------------------------------------------------------------*/
+ *--------------------------------------------------------------------------*/
var Prototype = {
- Version: '1.5.1',
+ Version: '1.6.0_rc0',
Browser: {
IE: !!(window.attachEvent && !window.opera),
Opera: !!window.opera,
WebKit: navigator.userAgent.indexOf('AppleWebKit/') > -1,
- Gecko: navigator.userAgent.indexOf('Gecko') > -1 && navigator.userAgent.indexOf('KHTML') == -1
+ Gecko: navigator.userAgent.indexOf('Gecko') > -1 && navigator.userAgent.indexOf('KHTML') == -1,
+ MobileSafari: !!navigator.userAgent.match(/iPhone.*Mobile.*Safari/)
},
BrowserFeatures: {
XPath: !!document.evaluate,
ElementExtensions: !!window.HTMLElement,
SpecificElementExtensions:
- (document.createElement('div').__proto__ !==
- document.createElement('form').__proto__)
+ document.createElement('div').__proto__ !==
+ document.createElement('form').__proto__
},
- ScriptFragment: '',
- JSONFilter: /^\/\*-secure-\s*(.*)\s*\*\/\s*$/,
+ ScriptFragment: '';
+
+ return $script;
+}
+
/**
\brief Récupère la valeur d'un champ, effectue un traitement Ajax et affiche le résultat
\param htmlname nom et id du champ
@@ -1,52 +1,111 @@
-/* Prototype JavaScript framework, version 1.5.1
+/* Prototype JavaScript framework, version 1.6.0_rc0
* (c) 2005-2007 Sam Stephenson
*